@@ -1,9 +1,13 @@
 """
 This module gathers the most important classes and helper functions used for scripting.
 """
+import sys
 import os
 import collections
 
+from itertools import chain
+from tabulate import tabulate
+
 ####################
 ### Monty import ###
 ####################
@@ -90,6 +94,8 @@ ext2file = collections.OrderedDict([
     (".out", AbinitOutputFile),
     (".log", AbinitLogFile),
     (".cif", Structure),
+    (".abivars", Structure),
+    (".ucell", Structure),
     ("POSCAR", Structure),
     (".cssr", Structure),
     (".cube", CubeFile),
@@ -150,8 +156,6 @@ def abiopen_ext2class_table():
     """
     Print the association table between file extensions and File classes.
     """
-    from itertools import chain
-    from tabulate import tabulate
     table = []
 
     for ext, cls in chain(ext2file.items(), abiext2ncfile.items()):
@@ -160,6 +164,29 @@ def abiopen_ext2class_table():
     return tabulate(table, headers=["Extension", "Class"])
 
 
+def extcls_supporting_panel(as_table=True, **tabulate_kwargs):
+    """
+    Return list of (ext, cls) tuples where ext is the file extension supporting the `get_panel` method
+    i.e files that can be integrated with the panel dashboard and `cls` the python class associated to it.
+    """
+    items = []
+
+    for ext, cls in chain(ext2file.items(), abiext2ncfile.items()):
+        if hasattr(cls, "get_panel"): items.append((ext, str(cls)))
+
+    if not as_table: return items
+
+    return tabulate(items, headers=["Extension", "Class"], **tabulate_kwargs)
+
+
+def abipanel(**kwargs):
+    """
+    Activate panel extensions used by AbiPy. Return panel module.
+    """
+    from abipy.panels.core import abipanel
+    return abipanel(**kwargs)
+
+
 def abifile_subclass_from_filename(filename):
     """
     Returns the appropriate class associated to the given filename.
@@ -313,14 +340,24 @@ def mjson_write(d, filepath, **kwargs):
         json.dump(d, fh, cls=MontyEncoder, **kwargs)
 
 
-def software_stack():
+def software_stack(as_dataframe=False):
     """
-    Import all the hard dependencies. Returns ordered dict: package --> string with version info.
+    Import all the hard dependencies and some optional packages.
+    Returns ordered dict: package --> string with version info or pandas dataframe if as_dataframe.
     """
     import platform
     system, node, release, version, machine, processor = platform.uname()
     # These packages are required
-    import numpy, scipy, netCDF4, pymatgen, apscheduler, pydispatch, yaml
+    import numpy, scipy, netCDF4, pymatgen, apscheduler, pydispatch, yaml, plotly
+
+    from importlib import import_module
+    def get_version(pkg_name):
+        """Return version of package from string."""
+        try:
+            mod = import_module(pkg_name)
+            return mod.__version__
+        except Exception:
+            return None
 
     try:
         from pymatgen.core import __version__ as pmg_version
@@ -337,17 +374,19 @@ def software_stack():
         ("apscheduler", apscheduler.version),
         ("pydispatch", pydispatch.__version__),
         ("yaml", yaml.__version__),
+        ("boken", get_version("bokeh")),
+        ("panel", get_version("panel")),
+        ("plotly", get_version("plotly")),
+        ("ase", get_version("ase")),
+        ("phonopy", get_version("phonopy")),
+        ("monty", get_version("monty")),
         ("pymatgen", pmg_version),
+        ("abipy", __version__),
     ])
 
-    # Optional but strongly suggested.
-    #try:
-    #    import matplotlib
-    #    d["matplotlib"] = "%s (backend: %s)" % (matplotlib.__version__, matplotlib.get_backend())
-    #except ImportError:
-    #    pass
-
-    return d
+    if not as_dataframe: return d
+    import pandas as pd
+    return pd.Series(data=d, name="version").to_frame().rename_axis("Package")
 
 
 def abicheck(verbose=0):
@@ -387,7 +426,6 @@ def abicheck(verbose=0):
     except Exception as exc:
         app(_straceback())
 
-    from tabulate import tabulate
     try:
         d = software_stack()
         cprint("Installed packages:", color="blue")
