@@ -500,10 +500,59 @@ class Function1D(object):
 
         return lines
 
+    def plotly_traces(self, fig, rcd=None, exchange_xy=False, xfactor=1, yfactor=1, *args, **kwargs):
+        """
+        Helper function to plot the function with plotly.
+
+        Args:
+            fig: |plotly.graph_objects.Figure|.
+            rcd: PlotlyRowColDesc object used when fig is not None to specify the (row, col) of the subplot in the grid.
+            exchange_xy: True to exchange the x and y in the plot.
+            xfactor, yfactor: xvalues and yvalues are multiplied by this factor before plotting.
+            args: Positional arguments passed to 'plotly.graph_objects.Scatter'
+            kwargs: Keyword arguments passed to 'plotly.graph_objects.Scatter'.
+                Accepts also AbiPy specific kwargs:
+
+        ==============  ===============================================================
+        kwargs          Meaning
+        ==============  ===============================================================
+        cplx_mode       string defining the data to print.
+                        Possible choices are (case-insensitive): `re` for the real part
+                        "im" for the imaginary part, "abs" for the absolute value.
+                        "angle" to display the phase of the complex number in radians.
+                        Options can be concatenated with "-"
+        ==============  ===============================================================
+        """
+        from abipy.tools.plotting import PlotlyRowColDesc
+        rcd = PlotlyRowColDesc.from_object(rcd)
+        ply_row, ply_col = rcd.ply_row, rcd.ply_col
+
+        import plotly.graph_objects as go
+
+        if self.iscomplexobj:
+            cplx_mode = kwargs.pop("cplx_mode", "re-im")
+        else:
+            cplx_mode = kwargs.pop("cplx_mode", "re")
+
+        showlegend = False
+        if "name" in kwargs: showlegend = True
+        showlegend = kwargs.pop("showlegend", showlegend)
+
+        for c in cplx_mode.lower().split("-"):
+            xx, yy = self.mesh, data_from_cplx_mode(c, self.values)
+            if xfactor != 1: xx = xx * xfactor
+            if yfactor != 1: yy = yy * yfactor
+
+            if exchange_xy:
+                xx, yy = yy, xx
+
+            fig.add_trace(go.Scatter(x=xx, y=yy, mode="lines", showlegend=showlegend, *args, **kwargs),
+                              row=ply_row, col=ply_col)
+
     @add_fig_kwargs
     def plot(self, ax=None, **kwargs):
         """
-        Plot the function.
+        Plot the function with matplotlib.
 
         Args:
             ax: |matplotlib-Axes| or None if a new figure should be created.
