@@ -17,8 +17,18 @@ with abiopen(abidata.ref_file("si_scf_WFK.nc")) as gs_wfk:
 # Compute the DOS with the Gaussian method (default)
 edos = gs_ebands.get_edos(method="gaussian", step=0.01, width=0.1)
 
-# Plot electron DOS and IDOS
+#%%
+# To plot electron DOS and IDOS with matplotlib use:
 edos.plot(title="Silicon DOS")
 
-# Plot electron DOS and IDOS
+#%%
+# For the plotly version use:
+edos.plotly(title="Silicon DOS")
+
+#%%
+# To plot electron DOS and IDOS with matplotlib use:
 edos.plot_dos_idos(title="DOS and Integrated DOS")
+
+#%%
+# For the plotly version use:
+edos.plotly_dos_idos(title="DOS and Integrated DOS")
