@@ -4,15 +4,14 @@ Gruneisen parameters
 ====================
 
 This example shows how to analyze the Gruneisen parameters
-computed by anaddb via finite difference. See also v8/Input/t45.in
+computed by anaddb via finite difference.
+See also v8/Input/t45.in
 """
-from __future__ import print_function, division
-
 import abipy.data as abidata
 from abipy import abilab
 
 # Open the file with abiopen
-# (alternatively one can use the shell and `abiopen.py OUT_GRUNS.nc -nb`
+# Alternatively one can use the shell and `abiopen.py OUT_GRUNS.nc -nb`
 # to open the file in a jupyter notebook.
 ncfile = abilab.abiopen(abidata.ref_file("mg2si_GRUNS.nc"))
 
@@ -25,7 +24,8 @@ ncfile.plot_phbands_with_gruns(title="Phonon bands with markers proportional to
 
 ncfile.plot_gruns_bs(title="Gruneisen along high-symmetry path.")
 
-ncfile.plot_phbands_with_gruns(fill_with="gruns_fd", title="Gruneisen parameters with finite differences.", with_doses=None)
+ncfile.plot_phbands_with_gruns(fill_with="gruns_fd",
+                               title="Gruneisen parameters with finite differences.", with_doses=None)
 
 ncfile.plot_gruns_scatter(units='cm-1',title="Scatter plot with Gruneisen parameters")
 
