@@ -120,7 +120,7 @@ class MpiRunner(object):
                            "--exe `which " + executable + "` ", stdin, stdout, stderr])
         else:
             if qad.mpi_procs != 1:
-                raise ValueError("Cannot use mpi_procs > when mpi_runner basename=%s" % basename)
+                raise ValueError(f"Cannot use mpi_procs `{qad.mpi_procs}` when mpi_runner: `{basename}`")
             cmd = " ".join([executable, stdin, stdout, stderr])
 
         return cmd
@@ -1018,7 +1018,7 @@ limits:
             # stderr is redirected to mods.err file.
             # module load 2>> mods.err
             se.add_comment("Load Modules")
-            se.add_line("module purge")
+            se.add_line("module --force purge")
             se.load_modules(self.modules)
             se.add_emptyline()
 
