@@ -20,7 +20,7 @@ from . import wrappers
 from .nodes import Dependency, Node, NodeError, NodeResults, FileNode #, check_spectator
 from .tasks import (Task, AbinitTask, ScfTask, NscfTask, DfptTask, PhononTask, ElasticTask, DdkTask, EffMassTask,
                     BseTask, RelaxTask, DdeTask, BecTask, ScrTask, SigmaTask, TaskManager,
-                    DteTask, EphTask, CollinearThenNonCollinearScfTask)
+                    DteTask, EphTask, KerangeTask, CollinearThenNonCollinearScfTask)
 
 from .utils import Directory
 from .netcdf import ETSF_Reader, NetcdfReader
@@ -50,6 +50,7 @@ __all__ = [
 
 
 class WorkResults(NodeResults):
+
     JSON_SCHEMA = NodeResults.JSON_SCHEMA.copy()
 
     @classmethod
@@ -460,11 +461,26 @@ class NodeContainer(metaclass=abc.ABCMeta):
         """Register an electron-phonon task."""
         kwargs["task_class"] = EphTask
         eph_inp = args[0]
-        seq_manager = TaskManager.from_user_config().new_with_fixed_mpi_omp(1, 1)
         if eph_inp.get("eph_frohlichm", 0) != 0 or abs(eph_inp.get("eph_task", 0)) == 15:
-            # FIXME: Hack to run task in sequential if calculation does not support MPI with nprocs > 1.
+            # FIXME: Hack to run task in sequential since this  calculation does
+            # not support MPI with nprocs > 1.
+            seq_manager = TaskManager.from_user_config().new_with_fixed_mpi_omp(1, 1)
             kwargs.update({"manager": seq_manager})
 
+        if eph_inp.get("eph_task",0) == -4:
+            max_cores = TaskManager.from_user_config().qadapter.max_cores
+            natom3 = 3 * len(eph_inp.structure)
+            nprocs = max(max_cores - max_cores % natom3, 1)
+            new_manager = TaskManager.from_user_config().new_with_fixed_mpi_omp(nprocs, 1)
+            kwargs.update({"manager": new_manager})
+
+        return self.register_task(*args, **kwargs)
+
+    def register_kerange_task(self, *args, **kwargs):
+        """ Register a kerange task."""
+        kwargs["task_class"] = KerangeTask
+        seq_manager = TaskManager.from_user_config().new_with_fixed_mpi_omp(1, 1)
+        kwargs.update({"manager": seq_manager})
         return self.register_task(*args, **kwargs)
 
     def walknset_vars(self, task_class=None, *args, **kwargs):
@@ -504,6 +520,7 @@ class Work(BaseWork, NodeContainer):
     .. rubric:: Inheritance Diagram
     .. inheritance-diagram:: Work
     """
+
     def __init__(self, workdir=None, manager=None):
         """
         Args:
@@ -584,6 +601,19 @@ class Work(BaseWork, NodeContainer):
     def __getitem__(self, slice):
         return self._tasks[slice]
 
+    def postpone_on_all_ok(self):
+        """
+        This method should be called when additional tasks are added to the Work at runtime.
+        e.g inside an on_all_ok method. This call triggers the allocations of new tasks
+        so that the scheduler will continue execution since new tasks have been added
+        and the finalized flag is set to False.
+        """
+        self.flow.allocate()
+        self.flow.build_and_pickle_dump()
+        self.finalized = False
+
+        return super().on_all_ok()
+
     def chunks(self, chunk_size):
         """Yield successive chunks of tasks of lenght chunk_size."""
         for tasks in chunks(self, chunk_size):
@@ -1086,7 +1116,7 @@ class RelaxWork(Work):
 
 class G0W0Work(Work):
     """
-    Work for general G0W0 calculations.
+    Work for generic G0W0 calculations.
     All input can be either single inputs or lists of inputs
 
     .. rubric:: Inheritance Diagram
@@ -1455,8 +1485,8 @@ class PhononWork(Work, MergeDdb):
     This work consists of nirred Phonon tasks where nirred is
     the number of irreducible atomic perturbations for a given set of q-points.
     It provides the callback method (on_all_ok) that calls mrgddb (mrgdv) to merge
-    all the partial DDB (POT) files produced. The two files are available in the
-    output directory of the Work.
+    all the partial DDB (POT) files produced.
+    The two files are available in the output directory of the Work.
 
     .. rubric:: Inheritance Diagram
     .. inheritance-diagram:: PhononWork
@@ -1464,7 +1494,7 @@ class PhononWork(Work, MergeDdb):
 
     @classmethod
     def from_scf_task(cls, scf_task, qpoints, is_ngqpt=False, tolerance=None, with_becs=False,
-                      ddk_tolerance=None, manager=None):
+                      ddk_tolerance=None, prtwf=-1, manager=None):
         """
         Construct a `PhononWork` from a |ScfTask| object.
         The input file for phonons is automatically generated from the input of the ScfTask.
@@ -1480,6 +1510,11 @@ class PhononWork(Work, MergeDdb):
             with_becs: Activate calculation of Electric field and Born effective charges.
             ddk_tolerance: dict {"varname": value} with the tolerance used in the DDK run if with_becs.
                 None to use AbiPy default.
+            prtwf: Controls the output of the first-order WFK.
+                By default we set it to -1 when q != 0 so that AbiPy is still able
+                to restart the DFPT task if the calculation is not converged (worst case scenario)
+                but we avoid the output of the 1-st WFK if the calculation converged successfully.
+                Non-linear DFT applications should not be affected since they assume q == 0.
             manager: |TaskManager| object.
         """
         if not isinstance(scf_task, ScfTask):
@@ -1494,16 +1529,19 @@ class PhononWork(Work, MergeDdb):
             new.add_becs_from_scf_task(scf_task, ddk_tolerance, ph_tolerance=tolerance)
 
         for qpt in qpoints:
-            if with_becs and np.sum(qpt ** 2) < 1e-12: continue
+            is_gamma = np.sum(qpt ** 2) < 1e-12
+            if with_becs and is_gamma: continue
             multi = scf_task.input.make_ph_inputs_qpoint(qpt, tolerance=tolerance)
             for ph_inp in multi:
+                # Here we set the value of prtwf for the DFPT tasks if q != Gamma.
+                if not is_gamma: ph_inp.set_vars(prtwf=prtwf)
                 new.register_phonon_task(ph_inp, deps={scf_task: "WFK"})
 
         return new
 
     @classmethod
     def from_scf_input(cls, scf_input, qpoints, is_ngqpt=False, tolerance=None,
-                       with_becs=False, ddk_tolerance=None, manager=None):
+                       with_becs=False, ddk_tolerance=None, prtwf=-1, manager=None):
         """
         Similar to `from_scf_task`, the difference is that this method requires
         an input for SCF calculation. A new |ScfTask| is created and added to the Work.
@@ -1522,9 +1560,12 @@ class PhononWork(Work, MergeDdb):
             new.add_becs_from_scf_task(scf_task, ddk_tolerance, ph_tolerance=tolerance)
 
         for qpt in qpoints:
-            if with_becs and np.sum(qpt ** 2) < 1e-12: continue
+            is_gamma = np.sum(qpt ** 2) < 1e-12
+            if with_becs and is_gamma: continue
             multi = scf_task.input.make_ph_inputs_qpoint(qpt, tolerance=tolerance)
             for ph_inp in multi:
+                # Here we set the value of prtwf for the DFPT tasks if q != Gamma.
+                if not is_gamma: ph_inp.set_vars(prtwf=prtwf)
                 new.register_phonon_task(ph_inp, deps={scf_task: "WFK"})
 
         return new
@@ -1533,7 +1574,7 @@ class PhononWork(Work, MergeDdb):
     def on_all_ok(self):
         """
         This method is called when all the q-points have been computed.
-        Ir runs `mrgddb` in sequential on the local machine to produce
+        It runs `mrgddb` in sequential on the local machine to produce
         the final DDB file in the outdir of the |Work|.
         """
         # Merge DDB files.
@@ -1977,12 +2018,14 @@ class ConducWork(Work):
     """
     Workflow for the computation of electrical conductivity.
 
-    Can be called from :
+    Can be called from:
         1. MultiDataset and PhononWork
         2. MultiDataset, DDB filepath and DVDB filepath.
+
     Can use Kerange Capability using withKerange=True
 
-    This work consists of 3 tasks or 5 tasks with kerange :
+    This work consists of 3 tasks or 5 tasks with kerange:
+
         1. SCF GS
         2. NSCF
         3. Kerange (Kerange only)
@@ -1994,7 +2037,7 @@ class ConducWork(Work):
     def from_phwork(cls, phwork, multi, nbr_proc=None, flow=None, with_kerange=False,
                     omp_nbr_thread=1, manager=None):
         """
-        Construct a |ConducWork| from a |PhononWork| and |MultiDataset|.
+        Construct a ConducWork from a |PhononWork| and |MultiDataset|.
 
         Args:
             phwork: a |PhononWork| object calculating the DDB and DVDB files.
@@ -2009,6 +2052,7 @@ class ConducWork(Work):
         # Verify phwork
         if not isinstance(phwork, PhononWork):
             raise TypeError("Work `%s` does not inherit from PhononWork" % phwork)
+
         # Verify Multi
         if (not with_kerange) and (multi.ndtset != 3): #Without kerange, multi should contain 3 datasets
             raise ValueError("""The |MultiDataset| object does not contain the expected number of dataset.
@@ -2051,7 +2095,7 @@ class ConducWork(Work):
     def from_filepath(cls, ddb_path, dvdb_path, multi, nbr_proc=None, flow=None,
                       with_kerange=False, omp_nbr_thread=1, manager=None):
         """
-        Construct a |ConducWork| from previously calculated DDB/DVDB file and |MultiDataset|.
+        Construct a ConducWork from previously calculated DDB/DVDB file and |MultiDataset|.
 
         Args:
             multi: a |MultiDataset| object containing a list of 3 datasets or 5 with Kerange.
@@ -2076,8 +2120,10 @@ class ConducWork(Work):
         # Make sure both file exists
         if not os.path.exists(ddb_path):
             raise ValueError("The DDB file doesn't exists : `%s`" % ddb_path)
+
         if not os.path.exists(dvdb_path):
             raise ValueError("The DVDB file doesn't exists : `%s`" % dvdb_path)
+
         # Verify nbr_proc and flow are defined if with_kerange
         if with_kerange and (flow is None or nbr_proc is None):
             raise ValueError("""When using kerange, the argument flow and nbr_proc must be passed to the function from_filepath
@@ -2089,7 +2135,7 @@ class ConducWork(Work):
         new.register_task(multi[1], deps={new[0]: "DEN"})
         taskNumber = 2 # To keep track of the task in new and multi
 
-        if(with_kerange): # Using Kerange
+        if with_kerange: # Using Kerange
             new.register_task(multi[2], deps={new[1]: "WFK"})
             new.register_task(multi[3], deps={new[0]: "DEN", new[1]: "WFK", new[2]: "KERANGE.nc"})
             taskNumber = 4 # We have 2 more task
@@ -2109,4 +2155,5 @@ class ConducWork(Work):
             if nbr_proc is not None:
                 for task in new[2:]:
                     task.with_fixed_mpi_omp(nbr_proc, omp_nbr_thread)
+
         return new
