@@ -36,14 +36,6 @@ def df_to_clipboard(options, df):
         df.to_clipboard()
 
 
-def abiview_fields(options):
-    """Animate fields with Mayavi. Accept any file with density or potential ..."""
-    from abipy.display.mvtk import MayaviFieldAnimator
-    a = MayaviFieldAnimator(options.filepath)
-    a.volume_animate()
-    return 0
-
-
 def abicomp_structure(options):
     """
     Compare crystalline structures. Use `--group` to compare for similarity.
@@ -320,8 +312,13 @@ def abicomp_edos(options):
                                        no_browser=options.no_browser)
 
     elif options.expose:
-        plotter.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
-                       verbose=options.verbose)
+        if options.plotly:
+            # Plotly version.
+            plotter.plotly_expose(chart_studio=options.chart_studio, verbose=options.verbose)
+        else:
+            # Matplotlib version.
+            plotter.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
+                           verbose=options.verbose)
 
     else:
         # Optionally, print info on gaps and their location
@@ -359,8 +356,14 @@ def abicomp_phbands(options):
                                        no_browser=options.no_browser)
 
     elif options.expose:
-        plotter.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
-                       verbose=options.verbose)
+        if options.plotly:
+            # Plotly version.
+            plotter.plotly_expose(chart_studio=options.chart_studio, verbose=options.verbose)
+        else:
+            # Matplotlib version.
+            plotter.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
+                            verbose=options.verbose)
+
     else:
         # Print pandas Dataframe.
         abilab.print_dataframe(plotter.get_phbands_frame())
@@ -374,7 +377,8 @@ def abicomp_phbands(options):
 
         # Select the plot method to call.
         if options.plot_mode == "panel":
-            plotter.get_panel().show()
+            #template=options.panel_template)
+            plotter.get_panel().show(debug=options.verbose > 0)
 
         elif options.plot_mode != "None":
             plotfunc = getattr(plotter, options.plot_mode, None)
@@ -398,8 +402,13 @@ def abicomp_phdos(options):
                       plotter=plotter)
 
     elif options.expose:
-        plotter.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
-                       verbose=options.verbose)
+        if options.plotly:
+            # Plotly version.
+            plotter.plotly_expose(chart_studio=options.chart_studio, verbose=options.verbose)
+        else:
+            # matplotlib version.
+            plotter.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
+                           verbose=options.verbose)
 
     elif options.notebook:
         plotter.make_and_open_notebook(foreground=options.foreground,
@@ -542,13 +551,6 @@ def abicomp_gkq(options):
         return _invoke_robot(options)
 
 
-#def abicomp_wrmax(options):
-#    """
-#    Compare multiple WRmax files with first order potential in real-space.
-#    """
-#    return _invoke_robot(options)
-
-
 def abicomp_v1qavg(options):
     """
     Compare multiple V1QAVG files with the average of the DFPT V1 potentials as function of q-point.
@@ -588,7 +590,7 @@ def abicomp_pseudos(options):
     return 0
 
 
-def _build_robot(options, trim_paths=False):
+def _build_robot(options, trim_paths=True):
     """Build robot instance from CLI options."""
     robot_cls = abilab.Robot.class_for_ext(options.command.upper())
 
@@ -638,14 +640,15 @@ def _invoke_robot(options):
                                      no_browser=options.no_browser)
 
     elif options.panel:
-        try:
-            import panel  # noqa: F401
-        except ImportError as exc:
-            cprint("Use `conda install panel` or `pip install panel` to install the python package.", "red")
-            raise exc
+        abilab.abipanel()
 
-        robot.get_panel().show()
-        return 0
+        if hasattr(robot, "get_panel"):
+            app = robot.get_panel(template=options.panel_template)
+            app.show(debug=options.verbose > 0)
+            return 0
+        else:
+            cprint(f"`{type(robot)} does not provide get_panel method", color="red")
+            return 1
 
     elif options.print or options.expose:
         robot.trim_paths()
@@ -668,12 +671,21 @@ def _invoke_robot(options):
         if not options.verbose:
             print("\nUse --verbose for more information")
 
-        if options.expose and hasattr(robot, "expose"):
-            robot.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
-                         verbose=options.verbose)
+        if options.expose:
 
-    #elif options.ipython:
+            if options.plotly:
+               # plotly version.
+               if hasattr(robot, "plotly_expose"):
+                    robot.plotly_expose(chart_studio=options.chart_studio, verbose=options.verbose)
+               else:
+                    cprint("<%s> does not implement plotly_expose method" % type(robot), color="red")
+
+            elif hasattr(robot, "expose"):
+                # matplotlib version.
+                robot.expose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
+                             verbose=options.verbose)
     else:
+        # Default behaviour: use ipython
         import IPython
         robot.trim_paths()
         IPython.embed(header=repr(robot) + "\n\nType `robot` in the terminal and use <TAB> to list its methods",
@@ -956,11 +968,16 @@ codes), a looser tolerance of 0.1 (the value used in Materials Project) is often
     # Parent parser for commands supporting expose
     expose_parser = argparse.ArgumentParser(add_help=False)
     expose_parser.add_argument("-e", '--expose', default=False, action="store_true",
-            help='Execute robot.expose to produce a pre-defined list of matplotlib figures.')
+            help='Execute robot.expose to produce a pre-defined list of (matplotlib|plotly) figures.')
     expose_parser.add_argument("-s", "--slide-mode", default=False, action="store_true",
             help="Used if --expose to iterate over figures. Expose all figures at once if not given on the CLI.")
     expose_parser.add_argument("-t", "--slide-timeout", type=int, default=None,
             help="Close figure after slide-timeout seconds (only if slide-mode). Block if not specified.")
+    expose_parser.add_argument("-ply", "--plotly", default=False, action="store_true",
+            help='Generate plotly plots in browser instead of matplotlib. WARNING: Not all the features are supported.')
+    expose_parser.add_argument("-cs", "--chart-studio", default=False, action="store_true",
+            help="Push figure to plotly chart studio ." +
+                 "Requires --plotly option and user account at https://chart-studio.plotly.com.")
 
     # Build the main parser.
     parser = argparse.ArgumentParser(epilog=get_epilog() if with_epilog else "",
@@ -1068,8 +1085,13 @@ the full set of atoms. Note that a value larger than 0.01 is considered to be un
     # Parent parser for *robot* commands
     robot_parser = argparse.ArgumentParser(add_help=False)
     robot_parser.add_argument('--no-walk', default=False, action="store_true", help="Don't enter subdirectories.")
-    robot_parser.add_argument('--panel', default=False, action="store_true",
+    robot_parser.add_argument("-pn", '--panel', default=False, action="store_true",
                               help="Open GUI in web browser, requires panel package. WARNING: Experimental")
+    robot_parser.add_argument("-pnt", "--panel-template", default="FastList", type=str,
+                              help="Specify template for panel dasboard." +
+                                   "Possible values are: FastList, FastGrid, Golden, Bootstrap, Material, React, Vanilla." +
+                                   "Default: FastList"
+                              )
 
     robot_parents = [copts_parser, robot_ipy_parser, robot_parser, expose_parser, pandas_parser]
     p_gsr = subparsers.add_parser('gsr', parents=robot_parents, help=abicomp_gsr.__doc__)
@@ -1129,6 +1151,10 @@ def main():
     except Exception:
         show_examples_and_exit(error_code=1)
 
+    # Plotly automatically activate expose mode.
+    if getattr(options, "plotly", None): options.expose = True
+    if getattr(options, "classic_notebook", None): options.notebook = True
+
     # loglevel is bound to the string value obtained from the command line argument.
     # Convert to upper case to allow the user to specify --loglevel=DEBUG or --loglevel=debug
     import logging
