@@ -701,7 +701,7 @@ Default: o
     p_graphviz.add_argument("-e", "--engine", type=str, default="automatic",
         help=("graphviz engine: ['dot', 'neato', 'twopi', 'circo', 'fdp', 'sfdp', 'patchwork', 'osage']. "
             "Default: automatic i.e. the engine is automatically selected. See http://www.graphviz.org/pdf/dot.1.pdf "
-            "Use `conda install python-graphviz` or `pip install graphviz` to install the python package"))
+            "Use `conda install python-graphviz` or `pip install graphviz` to install the python package."))
     p_graphviz.add_argument("-d", '--dirtree', default=False, action="store_true",
         help='Visualize files and directories in workdir instead of tasks/works.')
 
@@ -1270,8 +1270,19 @@ def main():
         else:
             graph = node.get_graphviz(engine=options.engine)
 
+        # Add this liine to print the DOT string
+        # Can be used with e.g. http://viz-js.com/
+        if options.verbose: print(graph)
+
         graph.view(directory=directory, cleanup=False)
 
+        if options.verbose > 1:
+            # Write graph to file in png format.
+            graph.format = "png"
+            graph.attr(dpi=str(300))
+            path = graph.render("graph", view=False, cleanup=False)
+            print("Saving png file to:", path)
+
     elif options.command == "listext":
         if not options.listexts:
             print("\nPlease specify the file extension(s), e.g. GSR SIGRES.\nList of available extensions:\n")
