@@ -346,6 +346,11 @@ closest points in this particular structure. This is usually what you want in a
 
     p_panel = subparsers.add_parser('panel', parents=[copts_parser, path_selector],
         help="Open GUI in web browser, requires panel package.")
+    p_panel.add_argument("-pnt", "--panel-template", default="FastList", type=str,
+                        help="Specify template for panel dasboard." +
+                             "Possible values are: FastList, FastGrid, Golden, Bootstrap, Material, React, Vanilla." +
+                             "Default: FastList"
+                        )
 
     # Subparser for kpath.
     p_kpath = subparsers.add_parser('kpath', parents=[copts_parser, path_selector],
@@ -604,6 +609,8 @@ def main():
                 print(sanitized)
 
         # Save file.
+        #print("sanitized structure\n", sanitized)
+        #print("lattice matrix:\n", sanitized.lattice.matrix)
         save_structure(sanitized, options)
 
     elif options.command == "primitive":
@@ -761,13 +768,9 @@ def main():
 
     elif options.command == "panel":
         structure = abilab.Structure.from_file(options.filepath)
-        try:
-            import panel  # noqa: F401
-        except ImportError as exc:
-            cprint("Use `conda install panel` or `pip install panel` to install the python package.", "red")
-            raise exc
-
-        structure.get_panel().show()  #threaded=True)
+        abilab.abipanel()
+        app = structure.get_panel(template=options.panel_template)
+        app.show(debug=options.verbose > 0)
         return 0
 
     elif options.command == "visualize":
