@@ -11,7 +11,7 @@ from monty.functools import prof_main
 from monty.termcolor import cprint
 from abipy import abilab
 from abipy.iotools.visualizer import Visualizer
-from abipy.tools.plotting import MplExpose, GenericDataFilePlotter
+from abipy.tools.plotting import MplExpose, PanelExpose, GenericDataFilePlotter, plotlyfigs_to_browser, push_to_chart_studio
 
 
 def handle_overwrite(path, options):
@@ -32,6 +32,14 @@ def df_to_clipboard(options, df):
         df.to_clipboard()
 
 
+#def abiview_fields(options):
+#    """Animate fields with Mayavi. Accept any file with density or potential ..."""
+#    from abipy.display.mvtk import MayaviFieldAnimator
+#    a = MayaviFieldAnimator(options.filepath)
+#    a.volume_animate()
+#    return 0
+
+
 def abiview_structure(options):
     """
     Visualize the structure with the specified visualizer. Requires external app
@@ -116,10 +124,12 @@ def abiview_ebands(options):
         elif options.bxsf:
             outpath = options.filepath + ".bxsf"
             abifile.ebands.to_bxsf(handle_overwrite(outpath, options))
+        #elif options.plotly:
+        #    print(abifile.to_string(verbose=options.verbose))
         else:
             print(abifile.to_string(verbose=options.verbose))
             abifile.expose_ebands(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout,
-                                  verbose=options.verbose)
+                                  expose_web=options.expose_web, verbose=options.verbose)
 
         return 0
 
@@ -181,36 +191,54 @@ asr: {asr}, chneut: {chneut}, dipdip: {dipdip}, lo_to_splitting: {lo_to_splittin
         print("Calculation completed.\nResults available in:", os.path.dirname(phbst_file.filepath))
 
         phbands = phbst_file.phbands
+        units = "mev"
 
         if options.xmgrace:
             outpath = options.filepath + ".agr"
             phbands.to_xmgrace(handle_overwrite(outpath, options))
             return 0
+
         #elif options.bxsf:
         #    outpath = options.filepath + ".bxsf"
         #    phbands.to_bxsf(handle_overwrite(outpath, options))
         #    return 0
+
         elif options.phononwebsite:
             return phbands.view_phononwebsite(browser=options.browser, verbose=options.verbose)
-        else:
+
+        elif options.plotly:
+            # Plotly + Panel version.
             phdos = phdos_file.phdos
-            units = "mev"
-            with MplExpose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout) as e:
-                #e(phbst_file.expose())
-                #e(phdos_file.expose())
-                e(phbands.qpoints.plot(show=False))
-                e(phbands.plot_with_phdos(phdos, units=units, show=False))
+            with PanelExpose(title=f"Vibrational properties of {phdos_file.structure.formula}") as e:
+                e(phbands.qpoints.plotly(show=False))
+                e(phbands.plotly_with_phdos(phdos, units=units, show=False))
+                e(phdos_file.plotly_pjdos_type(units=units, show=False))
+                e(phdos.plotly_harmonic_thermo(tstart=5, tstop=300, num=50, units="eV", formula_units=1,
+                                               quantities="all", show=False))
+                e(phdos.plotly(units=units, show=False))
                 e(phbands.plot_colored_matched(units=units, show=False))
                 e(phbands.plot_fatbands(units=units, phdos_file=phdos_file, show=False))
-                e(phdos.plot(units=units, show=False))
+                #push_to_chart_studio(figs) if options.chart_studio else plotlyfigs_to_browser(figs)
+
+        else:
+            phdos = phdos_file.phdos
+
+            if not options.expose_web:
+                # matplotlib figure and X-server.
+                e = MplExpose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout)
+            else:
+                # panel version with matplotlib.
+                e = PanelExpose(title=f"Vibrational properties of {phdos_file.structure.formula}")
+
+            with e:
+                e(phbands.qpoints.plot(show=False))
+                e(phbands.plot_with_phdos(phdos, units=units, show=False))
                 e(phdos_file.plot_pjdos_type(units=units, show=False))
-                #try
-                #    msq_dos = phdos_file.msq_dos
-                #except RuntimeError:
-                #    msq_dos = None
-                #if msq_dos is not None:
-                #    e(msq_dos.plot_uiso(show=False))
-                #    e(msq_dos.plot_uiso(show=False))
+                e(phbands.plot_colored_matched(units=units, show=False))
+                e(phdos.plot_harmonic_thermo(tstart=5, tstop=300, num=50, units="eV", formula_units=1,
+                             quantities="all", show=False))
+                e(phdos.plot(units=units, show=False))
+                e(phbands.plot_fatbands(units=units, phdos_file=phdos_file, show=False))
 
         phbst_file.close()
         phdos_file.close()
@@ -236,7 +264,7 @@ num_points: {num_points}, asr: {asr}, chneut: {chneut}, dipdip: {dipdip}
     df = sv.get_dataframe()
     abilab.print_dataframe(df, title="Speed of sound for different directions:")
     df_to_clipboard(options, df)
-    sv.plot()
+    sv.plotly if options.plotly else sv.plot()
 
     return 0
 
@@ -257,7 +285,10 @@ asr: {asr}, chneut: {chneut}, dipdip: {dipdip}
 
         gamma_ev = 1e-4
         print("Plotting dielectric tensor with constant phonon damping: %s (eV)" % gamma_ev)
-        tgen.plot_all(gamma_ev=gamma_ev)
+        if options.plotly:
+            tgen.plotly_all(gamma_ev=gamma_ev)
+        else:
+            tgen.plot_all(gamma_ev=gamma_ev)
 
     return 0
 
@@ -273,14 +304,16 @@ def abiview_ddb_asr(options):
                                      nqsmall=10, ndivsm=20, dos_method="tetra", ngqpt=None,
                                      verbose=0, mpi_procs=1)
 
-        plotter.plot()
+        title = ddb.structure.formula
+        renderer = "browser" if not options.chart_studio else "chart_studio"
+        plotter.combiplotly(renderer=renderer, title=title) if options.plotly else plotter.plot(title=title)
 
     return 0
 
 
 def abiview_ddb_dipdip(options):
     """
-    Compute phonon band structure from DDB with/without acoustic sum rule. Plot results.
+    Compute phonon band structure from DDB with/without dipole-dipole interaction. Plot results.
     """
     print("Computing phonon frequencies with/without dipdip")
 
@@ -289,7 +322,27 @@ def abiview_ddb_dipdip(options):
                                         nqsmall=10, ndivsm=20, dos_method="tetra", ngqpt=None,
                                         verbose=0, mpi_procs=1)
 
-        plotter.plot()
+        title = ddb.structure.formula
+        renderer = "browser" if not options.chart_studio else "chart_studio"
+        plotter.combiplotly(renderer=renderer, title=title) if options.plotly else plotter.plot(title=title)
+
+    return 0
+
+
+def abiview_ddb_quad(options):
+    """
+    Compute phonon band structure from DDB with/without quadrupole terms. Plot results.
+    """
+    print("Computing phonon frequencies with/without dip-quad and quad-quad terms.")
+
+    with abilab.abiopen(options.filepath) as ddb:
+        plotter = ddb.anacompare_quad(asr=2, chneut=1, dipdip=1, lo_to_splitting="automatic",
+                                      nqsmall=0, ndivsm=20, dos_method="tetra", ngqpt=None,
+                                      verbose=0, mpi_procs=1)
+
+        title = ddb.structure.formula
+        renderer = "browser" if not options.chart_studio else "chart_studio"
+        plotter.combiplotly(renderer=renderer, title=title) if options.plotly else plotter.plot(title=title)
 
     return 0
 
@@ -333,7 +386,15 @@ asr: {asr}, chneut: {chneut}, dipdip: {dipdip}
         # Execute anaddb to compute the interatomic force constants.
         ifc = ddb.anaget_ifc(asr=asr, chneut=chneut, dipdip=dipdip)
         #print(ifc)
-        with MplExpose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout) as e:
+
+        if not options.expose_web:
+            # matplotlib figure and X-server.
+            e = MplExpose(slide_mode=options.slide_mode, slide_timeout=options.slide_timeout)
+        else:
+            # panel version
+            e = PanelExpose(title=f"Interatomic force constants of {phdos_file.structure.formula}")
+
+        with e:
             e(ifc.plot_longitudinal_ifc(title="Longitudinal IFCs", show=False))
             e(ifc.plot_longitudinal_ifc_short_range(title="Longitudinal IFCs short range", show=False))
             e(ifc.plot_longitudinal_ifc_ewald(title="Longitudinal IFCs Ewald", show=False))
@@ -342,7 +403,9 @@ asr: {asr}, chneut: {chneut}, dipdip: {dipdip}
 
 
 def abiview_phbands(options):
-    """Plot phonon bands. Accept any file with PhononBands e.g. PHBST.nc, ..."""
+    """
+    Plot phonon bands. Accept any file with PhononBands e.g. PHBST.nc, ...
+    """
     with abilab.abiopen(options.filepath) as abifile:
         if options.xmgrace:
             outpath = options.filepath + ".agr"
@@ -441,8 +504,15 @@ Usage example:
     abiview.py ddb in_DDB                 ==>  Compute ph-bands and DOS from DDB, plot results.
     abiview.py ddb_vs                     ==>  Compute speed of sound from DDB by fitting phonon frequencies.
     abiview.py ddb_ir                     ==>  Compute infra-red spectrum from DDB. Plot results.
-    abiview.py ddb_asr                    ==>  Compute ph-bands from DDB with/wo acoustic rule. Plot results.
-    abiview.py ddb_dipdip                 ==>  Compute ph-bands from DDB with/wo dipole-dipole treatment. Plot results.
+    abiview.py ddb_asr                    ==>  Compute ph-bands from DDB with/wo acoustic rule.
+                                               Plot results with matplotlib (default) or plotly (--plotly)
+    abiview.py ddb_asr --plotly -cs       ==>  Compute ph-bands from DDB with/wo acoustic rule.
+                                               Plot results with plotly and push figure to plotly chart studio cloud.
+                                               See: https://chart-studio.plotly.com/
+    abiview.py ddb_dipdip                 ==>  Compute ph-bands from DDB with/wo dipole-dipole treatment.
+                                               Plot results with matplotlib (default) or plotly (--plotly)
+    abiview.py ddb_quad                   ==>  Compute ph-bands from DDB with/wo dipole-quadrupole terms.
+                                               Plot results with matplotlib (default) or plotly (--plotly)
     abiview.py ddb_ifc                    ==>  Visualize interatomic force constants in real space.
     abiview.py phbands out_PHBST.nc -web  ==>  Visualize ph-bands and displacements with phononwebsite.
 
@@ -485,6 +555,8 @@ def get_parser(with_epilog=False):
             help="Iterate over figures. Expose all figures at once if not given on the CLI.")
     slide_parser.add_argument("-t", "--slide-timeout", type=int, default=None,
             help="Close figure after slide-timeout seconds (only if slide-mode). Block if not specified.")
+    slide_parser.add_argument("-ew", "--expose-web", default=False, action="store_true",
+            help='Generate matplotlib plots in $BROWSER instead of X-server. WARNING: Not all the features are supported.')
 
     # Parent parser for commands that operating on pandas dataframes
     pandas_parser = argparse.ArgumentParser(add_help=False)
@@ -501,14 +573,13 @@ def get_parser(with_epilog=False):
     nb_parser.add_argument('--foreground', action='store_true', default=False,
         help="Run jupyter notebook in the foreground.")
 
-    # Parent parser for commands supporting expose.
-    #expose_parser = argparse.ArgumentParser(add_help=False)
-    #expose_parser.add_argument("-e", '--expose', default=False, action="store_true",
-    #        help='Execute robot.expose to produce a pre-defined list of matplotlib figures.')
-    #expose_parser.add_argument("-s", "--slide-mode", default=False, action="store_true",
-    #        help="Used if --expose to iterate over figures. Expose all figures at once if not given on the CLI.")
-    #expose_parser.add_argument("-t", "--slide-timeout", type=int, default=None,
-    #        help="Close figure after slide-timeout seconds (only if slide-mode). Block if not specified.")
+    # Parent parser for commands supporting plotly plots
+    plotly_parser = argparse.ArgumentParser(add_help=False)
+    plotly_parser.add_argument("-ply", '--plotly', default=False, action="store_true",
+        help='Generate plotly plots in browser instead of matplotlib.')
+    plotly_parser.add_argument("-cs", "--chart-studio", default=False, action="store_true",
+        help="Push figure to plotly chart studio. " +
+             "Requires --plotly and user account at https://chart-studio.plotly.com.")
 
     # Build the main parser.
     parser = argparse.ArgumentParser(epilog=get_epilog() if with_epilog else "",
@@ -571,7 +642,7 @@ def get_parser(with_epilog=False):
     p_dirviz.add_argument("-e", "--engine", type=str, default="fdp",
         help=("graphviz engine: ['dot', 'neato', 'twopi', 'circo', 'fdp', 'sfdp', 'patchwork', 'osage']. "
             "See http://www.graphviz.org/pdf/dot.1.pdf "
-            "Use `conda install python-graphviz` or `pip install graphviz` to install the python package"))
+            "Use `conda install python-graphviz` or `pip install graphviz` to install the python package."))
 
     # Subparser for ebands command.
     p_ebands = subparsers.add_parser('ebands', parents=[copts_parser, slide_parser], help=abiview_ebands.__doc__)
@@ -591,7 +662,7 @@ def get_parser(with_epilog=False):
         help="Application name. Possible options: mpl (matplotlib, default), xsf (xcrysden), mayavi.")
 
     # Subparser for ddb command.
-    p_ddb = subparsers.add_parser('ddb', parents=[copts_parser, slide_parser], help=abiview_ddb.__doc__)
+    p_ddb = subparsers.add_parser('ddb', parents=[copts_parser, slide_parser, plotly_parser], help=abiview_ddb.__doc__)
     add_args(p_ddb, "xmgrace", "phononweb", "browser", "force")
 
     # Subparser for ddb_vs command.
@@ -603,12 +674,16 @@ def get_parser(with_epilog=False):
                                      help=abiview_ddb_ir.__doc__)
 
     # Subparser for ddb_asr command.
-    p_ddb_asr = subparsers.add_parser('ddb_asr', parents=[copts_parser, pandas_parser, slide_parser],
+    p_ddb_asr = subparsers.add_parser('ddb_asr', parents=[copts_parser, pandas_parser, slide_parser, plotly_parser],
                                       help=abiview_ddb_asr.__doc__)
 
     # Subparser for ddb_dipdip command.
-    p_ddb_dipdip = subparsers.add_parser('ddb_dipdip', parents=[copts_parser, pandas_parser, slide_parser],
-                                          help=abiview_ddb_dipdip.__doc__)
+    p_ddb_dipdip = subparsers.add_parser('ddb_dipdip', parents=[copts_parser, pandas_parser, slide_parser, plotly_parser],
+                                         help=abiview_ddb_dipdip.__doc__)
+
+    # Subparser for ddb_quad command.
+    p_ddb_quad = subparsers.add_parser('ddb_quad', parents=[copts_parser, pandas_parser, slide_parser, plotly_parser],
+                                       help=abiview_ddb_quad.__doc__)
 
     # Subparser for ddb_ph_isodistort command.
     p_ddb_isodistort_ph = subparsers.add_parser('ddb_isodistort_ph', parents=[copts_parser],
@@ -669,8 +744,8 @@ def main():
         raise ValueError('Invalid log level: %s' % options.loglevel)
     logging.basicConfig(level=numeric_level)
 
-    if options.verbose > 2:
-        print(options)
+    if getattr(options, "plotly", False): options.expose = True
+    if options.verbose > 2: print(options)
 
     if options.mpl_backend is not None:
         # Set matplotlib backend
